# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class WatchAddressRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cashaddr': 'str',
        'url': 'str',
        'type': 'str',
        'recurrence': 'str',
        'token_id': 'object',
        'duration_sec': 'float'
    }

    attribute_map = {
        'cashaddr': 'cashaddr',
        'url': 'url',
        'type': 'type',
        'recurrence': 'recurrence',
        'token_id': 'tokenId',
        'duration_sec': 'duration_sec'
    }

    def __init__(self, cashaddr=None, url=None, type='transaction:in,out', recurrence='once', token_id=None, duration_sec=86400, local_vars_configuration=None):  # noqa: E501
        """WatchAddressRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cashaddr = None
        self._url = None
        self._type = None
        self._recurrence = None
        self._token_id = None
        self._duration_sec = None
        self.discriminator = None

        self.cashaddr = cashaddr
        self.url = url
        self.type = type
        if recurrence is not None:
            self.recurrence = recurrence
        self.token_id = token_id
        if duration_sec is not None:
            self.duration_sec = duration_sec

    @property
    def cashaddr(self):
        """Gets the cashaddr of this WatchAddressRequest.  # noqa: E501

        Cash address to watch   # noqa: E501

        :return: The cashaddr of this WatchAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._cashaddr

    @cashaddr.setter
    def cashaddr(self, cashaddr):
        """Sets the cashaddr of this WatchAddressRequest.

        Cash address to watch   # noqa: E501

        :param cashaddr: The cashaddr of this WatchAddressRequest.  # noqa: E501
        :type cashaddr: str
        """
        if self.local_vars_configuration.client_side_validation and cashaddr is None:  # noqa: E501
            raise ValueError("Invalid value for `cashaddr`, must not be `None`")  # noqa: E501

        self._cashaddr = cashaddr

    @property
    def url(self):
        """Gets the url of this WatchAddressRequest.  # noqa: E501

        Url to be called when configured action is triggered  # noqa: E501

        :return: The url of this WatchAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WatchAddressRequest.

        Url to be called when configured action is triggered  # noqa: E501

        :param url: The url of this WatchAddressRequest.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def type(self):
        """Gets the type of this WatchAddressRequest.  # noqa: E501

        Type of watch operation  # noqa: E501

        :return: The type of this WatchAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this WatchAddressRequest.

        Type of watch operation  # noqa: E501

        :param type: The type of this WatchAddressRequest.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["transaction:in", "transaction:out", "transaction:in,out", "balance", "slptransaction:in", "slptransaction:out", "slptransaction:in,out", "slpbalance"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def recurrence(self):
        """Gets the recurrence of this WatchAddressRequest.  # noqa: E501

        Action recurrence. Indicates if webhook should be triggered recurrently until expire or only once  # noqa: E501

        :return: The recurrence of this WatchAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._recurrence

    @recurrence.setter
    def recurrence(self, recurrence):
        """Sets the recurrence of this WatchAddressRequest.

        Action recurrence. Indicates if webhook should be triggered recurrently until expire or only once  # noqa: E501

        :param recurrence: The recurrence of this WatchAddressRequest.  # noqa: E501
        :type recurrence: str
        """
        allowed_values = ["once", "recurrent"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and recurrence not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `recurrence` ({0}), must be one of {1}"  # noqa: E501
                .format(recurrence, allowed_values)
            )

        self._recurrence = recurrence

    @property
    def token_id(self):
        """Gets the token_id of this WatchAddressRequest.  # noqa: E501

        Token unique hexadecimal identifier to use. Mandatory in SLP webhooks.  # noqa: E501

        :return: The token_id of this WatchAddressRequest.  # noqa: E501
        :rtype: object
        """
        return self._token_id

    @token_id.setter
    def token_id(self, token_id):
        """Sets the token_id of this WatchAddressRequest.

        Token unique hexadecimal identifier to use. Mandatory in SLP webhooks.  # noqa: E501

        :param token_id: The token_id of this WatchAddressRequest.  # noqa: E501
        :type token_id: object
        """

        self._token_id = token_id

    @property
    def duration_sec(self):
        """Gets the duration_sec of this WatchAddressRequest.  # noqa: E501

        Duration of the webhook lifetime in seconds before it will expire.  # noqa: E501

        :return: The duration_sec of this WatchAddressRequest.  # noqa: E501
        :rtype: float
        """
        return self._duration_sec

    @duration_sec.setter
    def duration_sec(self, duration_sec):
        """Sets the duration_sec of this WatchAddressRequest.

        Duration of the webhook lifetime in seconds before it will expire.  # noqa: E501

        :param duration_sec: The duration_sec of this WatchAddressRequest.  # noqa: E501
        :type duration_sec: float
        """

        self._duration_sec = duration_sec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WatchAddressRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WatchAddressRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from mainnet.models.balance_request import BalanceRequest
from mainnet.models.balance_response import BalanceResponse
from mainnet.models.cashscript_receipt import CashscriptReceipt
from mainnet.models.contract import Contract
from mainnet.models.contract_fn_request import ContractFnRequest
from mainnet.models.contract_fn_response import ContractFnResponse
from mainnet.models.contract_info_request import ContractInfoRequest
from mainnet.models.contract_info_response import ContractInfoResponse
from mainnet.models.contract_request import ContractRequest
from mainnet.models.contract_response import ContractResponse
from mainnet.models.convert_request import ConvertRequest
from mainnet.models.create_signed_message_request import CreateSignedMessageRequest
from mainnet.models.deposit_address_response import DepositAddressResponse
from mainnet.models.electrum_raw_transaction import ElectrumRawTransaction
from mainnet.models.electrum_raw_transaction_script_pub_key import ElectrumRawTransactionScriptPubKey
from mainnet.models.electrum_raw_transaction_script_sig import ElectrumRawTransactionScriptSig
from mainnet.models.electrum_raw_transaction_vin import ElectrumRawTransactionVin
from mainnet.models.electrum_raw_transaction_vout import ElectrumRawTransactionVout
from mainnet.models.error import Error
from mainnet.models.escrow_contract import EscrowContract
from mainnet.models.escrow_fn_request import EscrowFnRequest
from mainnet.models.escrow_info_request import EscrowInfoRequest
from mainnet.models.escrow_info_response import EscrowInfoResponse
from mainnet.models.escrow_request import EscrowRequest
from mainnet.models.escrow_response import EscrowResponse
from mainnet.models.get_addresses_response import GetAddressesResponse
from mainnet.models.get_testnet_bch_request import GetTestnetBchRequest
from mainnet.models.get_testnet_bch_response import GetTestnetBchResponse
from mainnet.models.get_testnet_slp_request import GetTestnetSlpRequest
from mainnet.models.get_testnet_slp_response import GetTestnetSlpResponse
from mainnet.models.max_amount_to_send_request import MaxAmountToSendRequest
from mainnet.models.mine_request import MineRequest
from mainnet.models.network_enum import NetworkEnum
from mainnet.models.op_return_data import OpReturnData
from mainnet.models.scalable_vector_graphic import ScalableVectorGraphic
from mainnet.models.send_max_request import SendMaxRequest
from mainnet.models.send_max_response import SendMaxResponse
from mainnet.models.send_request import SendRequest
from mainnet.models.send_request_item import SendRequestItem
from mainnet.models.send_request_item_any_of import SendRequestItemAnyOf
from mainnet.models.send_request_options import SendRequestOptions
from mainnet.models.send_response import SendResponse
from mainnet.models.serialized_wallet import SerializedWallet
from mainnet.models.signed_message_response import SignedMessageResponse
from mainnet.models.signed_message_response_details import SignedMessageResponseDetails
from mainnet.models.signed_message_response_raw import SignedMessageResponseRaw
from mainnet.models.slp_balance_request import SlpBalanceRequest
from mainnet.models.slp_balance_response import SlpBalanceResponse
from mainnet.models.slp_deposit_address_response import SlpDepositAddressResponse
from mainnet.models.slp_genesis_request import SlpGenesisRequest
from mainnet.models.slp_genesis_response import SlpGenesisResponse
from mainnet.models.slp_mint_request import SlpMintRequest
from mainnet.models.slp_mint_response import SlpMintResponse
from mainnet.models.slp_outpoints_response import SlpOutpointsResponse
from mainnet.models.slp_send_max_request import SlpSendMaxRequest
from mainnet.models.slp_send_request import SlpSendRequest
from mainnet.models.slp_send_request_item import SlpSendRequestItem
from mainnet.models.slp_send_request_options import SlpSendRequestOptions
from mainnet.models.slp_send_response import SlpSendResponse
from mainnet.models.slp_token_info_request import SlpTokenInfoRequest
from mainnet.models.slp_token_info_response import SlpTokenInfoResponse
from mainnet.models.slp_utxo import SlpUtxo
from mainnet.models.slp_utxo_response import SlpUtxoResponse
from mainnet.models.unit_type import UnitType
from mainnet.models.util_decode_transaction_request import UtilDecodeTransactionRequest
from mainnet.models.utxo import Utxo
from mainnet.models.utxo_response import UtxoResponse
from mainnet.models.verify_signed_message_request import VerifySignedMessageRequest
from mainnet.models.verify_signed_message_response import VerifySignedMessageResponse
from mainnet.models.verify_signed_message_response_details import VerifySignedMessageResponseDetails
from mainnet.models.wallet_info import WalletInfo
from mainnet.models.wallet_mnemonic import WalletMnemonic
from mainnet.models.wallet_named_exists_request import WalletNamedExistsRequest
from mainnet.models.wallet_replace_named_request import WalletReplaceNamedRequest
from mainnet.models.wallet_request import WalletRequest
from mainnet.models.wallet_response import WalletResponse
from mainnet.models.wallet_type import WalletType
from mainnet.models.watch_address_request import WatchAddressRequest
from mainnet.models.watch_address_response import WatchAddressResponse
from mainnet.models.wif import Wif
from mainnet.models.zero_balance_response import ZeroBalanceResponse
